nl_langinfo

Function nl_langinfo 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn nl_langinfo(item: nl_item) -> *mut c_char
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/nl_langinfo.html.

Get a string from the langinfo table

Safety

  • Caller must ensure item is a valid nl_item index.
  • Returns a pointer to a null-terminated string, or an empty string if the item is invalid.
  • Compatibility requires mutable pointer to be returned, but it should not be mutated!