pub type nl_item = size_t;Expand description
See https://pubs.opengroup.org/onlinepubs/9799919799/basedefs/langinfo.h.html.
POSIX type for items used with nl_langinfo
In practice, this is an index into the string table.
pub type nl_item = size_t;See https://pubs.opengroup.org/onlinepubs/9799919799/basedefs/langinfo.h.html.
POSIX type for items used with nl_langinfo
In practice, this is an index into the string table.